@@ -2,7 +2,7 @@
 
 APP='Tanglet'
 BUNDLE="$APP.app"
-VERSION='1.5.6'
+VERSION='1.6.1.1'
 
 # Remove any previous disk folder or DMG
 echo -n 'Preparing... '
@@ -18,7 +18,7 @@ echo -n 'Copying application bundle... '
 mkdir "$APP"
 cp -Rf "$BUNDLE" "$APP/"
 strip "$APP/$BUNDLE/Contents/MacOS/$APP"
-cp COPYING "$APP/License.txt"
+cp LICENSES/GPL-3.0-or-later.txt "$APP/License.txt"
 echo 'Done'
 
 # Create ReadMe
@@ -45,6 +45,14 @@ mkdir "$TRANSLATIONS"
 cp translations/*.qm "$TRANSLATIONS"
 echo 'Done'
 
+# Make macOS aware that the app bundle is translated.
+# This is required to translate parts of native open/save dialogs.
+echo -n 'Creating mac lproj directories for translations... '
+for translation in $(ls translations | grep qm | cut -d'.' -f1 | cut -d'_' -f2- | uniq); do
+    mkdir -p "$APP/$BUNDLE/Contents/Resources/${translation}.lproj"
+done
+echo 'Done'
+
 # Copy Qt translations
 echo -n 'Copying Qt translations... '
 cp $QTDIR/translations/qt_* "$TRANSLATIONS"
