@@ -1,79 +1,132 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2011, 2013, 2014 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "trie.h"
 
+#include <QDataStream>
+#include <QTextStream>
+
 #include <queue>
 #include <utility>
-#include <QDataStream>
 
 //-----------------------------------------------------------------------------
 
 namespace
 {
 
+/**
+ * @brief The TrieGenerator class generates the optimized word list for the trie class.
+ */
 class TrieGenerator
 {
 public:
-	TrieGenerator(const QChar& key = QChar())
-	: m_key(key), m_word(false), m_children(0), m_next(0), m_count(0)
+	/**
+	 * Constructs a generator instance.
+	 * @param key the letter contained by the generator instance
+	 */
+	explicit TrieGenerator(const QChar& key = QChar())
+		: m_key(key)
+		, m_word(false)
+		, m_children(nullptr)
+		, m_next(nullptr)
+		, m_count(0)
 	{
 	}
 
-	TrieGenerator(const QString& word)
-	: m_word(false), m_children(0), m_next(0), m_count(0)
+	/**
+	 * Constructs a generator instance.
+	 * @param word a list of letters to build child instances from
+	 */
+	explicit TrieGenerator(const QString& word)
+		: m_word(false)
+		, m_children(nullptr)
+		, m_next(nullptr)
+		, m_count(0)
 	{
 		addWord(word, QStringList(word));
 	}
 
-	TrieGenerator(const QHash<QString, QStringList>& words);
+	/**
+	 * Constructs a generator instance.
+	 * @param data contents of a word list file including alternate spellings
+	 */
+	explicit TrieGenerator(const QByteArray& data);
 
+	/**
+	 * Destroys the generator.
+	 */
 	~TrieGenerator();
 
+	/**
+	 * Compiles a compressed list of the trie for faster access.
+	 * @param [out] nodes the compressed list of nodes
+	 * @param [out] spellings the list of spellings
+	 */
 	void run(QVector<Trie::Node>& nodes, QStringList& spellings) const;
 
 private:
+	/**
+	 * Fetch a child generator matching a specific letter. Creates one if does not exist yet.
+	 * @param letter the letter to add
+	 * @return the child generator
+	 */
 	TrieGenerator* addChild(const QChar& letter);
+
+	/**
+	 * Adds a word by walking through the letters and fetching the next child of each letter.
+	 * @param word the word to add
+	 * @param spellings alternate spellings of the word to store
+	 */
 	void addWord(const QString& word, const QStringList& spellings);
 
 	// Uncopyable
-	TrieGenerator(const TrieGenerator&);
-	TrieGenerator& operator=(const TrieGenerator&);
+	TrieGenerator(const TrieGenerator&) = delete;
+	TrieGenerator& operator=(const TrieGenerator&) = delete;
 
 private:
-	QChar m_key;
-	bool m_word;
-	TrieGenerator* m_children;
-	TrieGenerator* m_next;
-	int m_count;
-	QStringList m_spellings;
+	QChar m_key; /**< letter represented by the generator */
+	bool m_word; /**< is this node a word */
+	TrieGenerator* m_children; /**< first child generator */
+	TrieGenerator* m_next; /**< first sibling generator */
+	int m_count; /**< how many children the generator has */
+	QStringList m_spellings; /**< alternate spellings of word */
 };
 
 //-----------------------------------------------------------------------------
 
-TrieGenerator::TrieGenerator(const QHash<QString, QStringList>& words)
-: m_word(false), m_children(0), m_next(0), m_count(0)
+TrieGenerator::TrieGenerator(const QByteArray& data)
+	: m_word(false)
+	, m_children(nullptr)
+	, m_next(nullptr)
+	, m_count(0)
 {
-	QHashIterator<QString, QStringList> i(words);
-	while (i.hasNext()) {
-		i.next();
-		addWord(i.key(), i.value());
+	QTextStream stream(data);
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+	stream.setCodec("UTF-8");
+#endif
+	while (!stream.atEnd()) {
+#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
+		QStringList spellings = stream.readLine().simplified().split(QChar(' '), Qt::SkipEmptyParts);
+#else
+		QStringList spellings = stream.readLine().simplified().split(QChar(' '), QString::SkipEmptyParts);
+#endif
+		if (spellings.isEmpty()) {
+			continue;
+		}
+
+		QString word = spellings.first().toUpper();
+		if (spellings.count() == 1) {
+			spellings[0] = word.toLower();
+		} else {
+			spellings.removeFirst();
+		}
+
+		if (word.length() >= 3 && word.length() <= 25) {
+			addWord(word, spellings);
+		}
 	}
 }
 
@@ -82,10 +135,7 @@ TrieGenerator::TrieGenerator(const QHash<QString, QStringList>& words)
 TrieGenerator::~TrieGenerator()
 {
 	delete m_children;
-	m_children = 0;
-
 	delete m_next;
-	m_next = 0;
 }
 
 //-----------------------------------------------------------------------------
@@ -98,7 +148,7 @@ TrieGenerator* TrieGenerator::addChild(const QChar& letter)
 		return m_children;
 	}
 
-	TrieGenerator* previous = 0;
+	TrieGenerator* previous = nullptr;
 	TrieGenerator* current = m_children;
 	while (current && current->m_key != letter) {
 		previous = current;
@@ -128,7 +178,7 @@ void TrieGenerator::addWord(const QString& word, const QStringList& spellings)
 
 void TrieGenerator::run(QVector<Trie::Node>& nodes, QStringList& spellings) const
 {
-	std::queue< std::pair<const TrieGenerator*, int> > next;
+	std::queue<std::pair<const TrieGenerator*, int>> next;
 	nodes.append(Trie::Node());
 	next.emplace(this, 0);
 
@@ -177,9 +227,9 @@ Trie::Trie(const QString& word)
 
 //-----------------------------------------------------------------------------
 
-Trie::Trie(const QHash<QString, QStringList>& words)
+Trie::Trie(const QByteArray& data)
 {
-	TrieGenerator generator(words);
+	TrieGenerator generator(data);
 	generator.run(m_nodes, m_spellings);
 	checkNodes();
 }
@@ -197,11 +247,10 @@ void Trie::clear()
 void Trie::checkNodes()
 {
 	// Verify that no nodes reference outside list
-	int count = m_nodes.size();
-	int start, end;
-	for (int i = 0; i < count; ++i) {
-		start = m_nodes[i].m_children;
-		end = start + m_nodes[i].m_child_count;
+	const quint32 count = m_nodes.size();
+	for (const Node& node : qAsConst(m_nodes)) {
+		const quint32 start = node.m_children;
+		const quint32 end = start + node.m_child_count;
 		if ((start >= count) || (end > count)) {
 			clear();
 			break;
@@ -213,13 +262,13 @@ void Trie::checkNodes()
 
 const Trie::Node* Trie::child(const QChar& letter, const Node* node) const
 {
-	int end = node->m_children + node->m_child_count;
-	for (int i = node->m_children; i < end; ++i) {
-		if (m_nodes[i] == letter) {
-			return &m_nodes[i];
+	const auto end = m_nodes.cbegin() + node->m_children + node->m_child_count;
+	for (auto i = m_nodes.cbegin() + node->m_children; i < end; ++i) {
+		if (*i == letter) {
+			return &*i;
 		}
 	}
-	return 0;
+	return nullptr;
 }
 
 //-----------------------------------------------------------------------------
@@ -227,27 +276,21 @@ const Trie::Node* Trie::child(const QChar& letter, const Node* node) const
 QStringList Trie::spellings(const QString& word, const QStringList& default_value) const
 {
 	const Trie::Node* node = &m_nodes[0];
-	int length = word.length();
+	const int length = word.length();
 	for (int i = 0; i < length; ++i) {
 		node = child(word.at(i), node);
-		if (node == 0) {
-			break;
+		if (!node) {
+			return default_value;
 		}
 	}
-
-	if (node) {
-		return m_spellings.mid(node->m_word, node->m_word_count);
-	} else {
-		return default_value;
-	}
+	return m_spellings.mid(node->m_word, node->m_word_count);
 }
 
 //-----------------------------------------------------------------------------
 
 QDataStream& operator<<(QDataStream& stream, const Trie& trie)
 {
-	stream << trie.m_nodes;
-	stream << trie.m_spellings;
+	stream << trie.m_nodes << trie.m_spellings.join('\n');
 	return stream;
 }
 
@@ -255,10 +298,11 @@ QDataStream& operator<<(QDataStream& stream, const Trie& trie)
 
 QDataStream& operator>>(QDataStream& stream, Trie& trie)
 {
-	stream >> trie.m_nodes;
+	QString spellings;
+	stream >> trie.m_nodes >> spellings;
 	trie.checkNodes();
 	if (!trie.isEmpty()) {
-		stream >> trie.m_spellings;
+		trie.m_spellings = spellings.split('\n');
 	}
 	return stream;
 }
