@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2009-2021 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "window.h"
 
@@ -28,17 +15,15 @@
 #include "scores_dialog.h"
 
 #include <QAction>
+#include <QActionGroup>
 #include <QApplication>
-#include <QCloseEvent>
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QDragEnterEvent>
 #include <QDropEvent>
 #include <QFile>
 #include <QFileDialog>
-#include <QFormLayout>
 #include <QLabel>
-#include <QLineEdit>
 #include <QMenu>
 #include <QMenuBar>
 #include <QMessageBox>
@@ -52,147 +37,317 @@
 #include <QTextStream>
 #include <QVBoxLayout>
 
-#include <ctime>
-
 //-----------------------------------------------------------------------------
 
-class Window::State {
+/**
+ * @brief The Window::State class controls which central widget is shown in the main window.
+ */
+class Window::State
+{
 public:
-	State(Window* window)
-		: m_window(window) { }
+	/**
+	 * Constructs a state instance.
+	 * @param window the window to control
+	 */
+	explicit State(Window* window)
+		: m_window(window)
+	{
+	}
 
+	/**
+	 * Destroys a state instance.
+	 */
 	virtual ~State() { }
 
+	/**
+	 * Handle the state being entered.
+	 */
 	virtual void enter() { }
-	virtual void newGame() { setState("NewGame"); }
-	virtual void openGame() { setState("OpenGame"); }
+
+	/**
+	 * Handle request to switch to the new game state.
+	 */
+	virtual void newGame()
+	{
+		setState("NewGame");
+	}
+
+	/**
+	 * Handle request to switch to the open game state.
+	 */
+	virtual void openGame()
+	{
+		setState("OpenGame");
+	}
+
+	/**
+	 * Handle request to switch to the optimizing state.
+	 */
 	virtual void optimizingStarted() { }
+
+	/**
+	 * Handle request to switch back from the optimizing state.
+	 */
 	virtual void optimizingFinished() { }
+
+	/**
+	 * Handle request to switch to the play state.
+	 */
 	virtual void play() { }
+
+	/**
+	 * Handle request to switch to the automatically paused state.
+	 */
 	virtual void autoPause() { }
+
+	/**
+	 * Handle request to switch back from the automatically paused state.
+	 */
 	virtual void autoResume() { }
+
+	/**
+	 * Handle request to switch to the paused state.
+	 */
 	virtual void pause() { }
+
+	/**
+	 * Handle request to switch back from the paused state.
+	 */
 	virtual void resume() { }
-	virtual void finish() { setState("Finish"); }
+
+	/**
+	 * Handle request to switch to the finished state.
+	 */
+	virtual void finish()
+	{
+		setState("Finish");
+	}
 
 protected:
-	void setPaused(bool paused) {
+	/**
+	 * Pause or resume the game.
+	 * @param paused whether to pause or resume
+	 */
+	void setPaused(bool paused)
+	{
 		m_window->m_board->setPaused(paused);
 		m_window->m_pause_action->setChecked(paused);
 	}
 
-	void setContentsIndex(int index) {
+	/**
+	 * Set which widget is shown in the main window.
+	 * @param index
+	 */
+	void setContentsIndex(int index)
+	{
 		m_window->m_contents->setCurrentIndex(index);
 	}
 
-	void setState(const QString& state) {
+	/**
+	 * Sets the current state of the main window.
+	 * @param state which state to switch to
+	 */
+	void setState(const QString& state)
+	{
 		m_window->m_previous_state = m_window->m_state;
 		m_window->m_state = m_window->m_states.value(state);
 		m_window->m_state->enter();
 	}
 
-	void setPreviousState() {
+	/**
+	 * Restores the previous state of the main window.
+	 */
+	void setPreviousState()
+	{
 		m_window->m_state = m_window->m_previous_state;
 		m_window->m_state->enter();
-		m_window->m_previous_state = 0;
+		m_window->m_previous_state = nullptr;
 	}
 
 private:
-	Window* m_window;
+	Window* m_window; /**< window to control */
 };
 
 //-----------------------------------------------------------------------------
 
-class Window::NewGameState : public Window::State {
+/**
+ * The Window::NewGameState class is a temporary state that shows a load screen while generating a
+ * board before switching to the Play state. It will also show the automatic pause screen and the
+ * optimizing screen if necessary.
+ */
+class Window::NewGameState : public Window::State
+{
 public:
-	NewGameState(Window* window)
-		: State(window) { }
+	explicit NewGameState(Window* window)
+		: State(window)
+	{
+	}
 
-	void enter() {
+	void enter() override
+	{
 		m_next_state = "Play";
 		setPaused(true);
 		setContentsIndex(4);
 	}
 
-	void optimizingStarted() { setState("Optimizing"); }
-	void play() { setState(m_next_state); }
-	void autoPause() { m_next_state = "AutoPause"; }
-	void autoResume() { m_next_state = "Play"; }
+	void optimizingStarted() override
+	{
+		setState("Optimizing");
+	}
+
+	void play() override
+	{
+		setState(m_next_state);
+	}
+
+	void autoPause() override
+	{
+		m_next_state = "AutoPause";
+	}
+
+	void autoResume() override
+	{
+		m_next_state = "Play";
+	}
 
 private:
-	QString m_next_state;
+	QString m_next_state; /**< state to enter once the game has been started */
 };
 
 //-----------------------------------------------------------------------------
 
-class Window::OpenGameState : public Window::State {
+/**
+ * The Window::OpenGameState class is a temporary state that shows a load screen while opening a
+ * board before switching to the Play state. It will also show the automatic pause screen and the
+ * optimizing screen if necessary.
+ */
+class Window::OpenGameState : public Window::State
+{
 public:
-	OpenGameState(Window* window)
-		: State(window) { }
+	explicit OpenGameState(Window* window)
+		: State(window)
+	{
+	}
 
-	void enter() {
+	void enter() override
+	{
 		m_next_state = "Play";
 		setPaused(true);
 		setContentsIndex(2);
 	}
 
-	void optimizingStarted() { setState("Optimizing"); }
-	void play() { setState(m_next_state); }
-	void autoPause() { m_next_state = "AutoPause"; }
-	void autoResume() { m_next_state = "Play"; }
+	void optimizingStarted() override
+	{
+		setState("Optimizing");
+	}
+
+	void play() override
+	{
+		setState(m_next_state);
+	}
+
+	void autoPause() override
+	{
+		m_next_state = "AutoPause";
+	}
+
+	void autoResume() override
+	{
+		m_next_state = "Play";
+	}
 
 private:
-	QString m_next_state;
+	QString m_next_state; /**< state to enter once the game has been loaded */
 };
 
 //-----------------------------------------------------------------------------
 
-class Window::OptimizingState : public Window::State {
+/**
+ * The Window::OptimizingState class shows the optimizing screen while the word list is being
+ * optimized and then switches back to the previous state.
+ */
+class Window::OptimizingState : public Window::State
+{
 public:
-	OptimizingState(Window* window)
-		: State(window) { }
+	explicit OptimizingState(Window* window)
+		: State(window)
+	{
+	}
 
-	void enter() {
+	void enter() override
+	{
 		setContentsIndex(5);
 	}
 
-	void optimizingFinished() { setPreviousState(); }
+	void optimizingFinished() override
+	{
+		setPreviousState();
+	}
 };
 
 //-----------------------------------------------------------------------------
 
-class Window::PlayState : public Window::State {
+/**
+ * The Window::PlayState class shows the play area. It will switch to the automatic pause or regular
+ * pause screen if needed.
+ */
+class Window::PlayState : public Window::State
+{
 public:
-	PlayState(Window* window)
-		: State(window) { }
+	explicit PlayState(Window* window)
+		: State(window)
+	{
+	}
 
-	void enter() {
+	void enter() override
+	{
 		setPaused(false);
 		setContentsIndex(0);
 	}
 
-	void autoPause() { setState("AutoPause"); }
-	void pause() { setState("Pause"); }
+	void autoPause() override
+	{
+		setState("AutoPause");
+	}
+
+	void pause() override
+	{
+		setState("Pause");
+	}
 };
 
 //-----------------------------------------------------------------------------
 
-class Window::AutoPauseState : public Window::State {
+/**
+ * The Window::AutoPauseState class will show the pause screen until it its reference count of times
+ * called is reduced to 0, at which point it will show the previous state. If any state is requested,
+ * it will switch to that instead.
+ *
+ * This state is used to temporarily pause the game while a menu is shown.
+ */
+class Window::AutoPauseState : public Window::State
+{
 public:
-	AutoPauseState(Window* window)
-		: State(window), m_count(0) { }
+	explicit AutoPauseState(Window* window)
+		: State(window)
+		, m_count(0)
+	{
+	}
 
-	void enter() {
+	void enter() override
+	{
 		setPaused(true);
 		setContentsIndex(1);
 		m_count++;
 	}
 
-	void autoPause() {
+	void autoPause() override
+	{
 		m_count++;
 	}
 
-	void autoResume() {
+	void autoResume() override
+	{
 		m_count--;
 		if (m_count < 1) {
 			m_count = 0;
@@ -200,39 +355,83 @@ public:
 		}
 	}
 
-	void newGame() { m_count = 0; setState("NewGame"); }
-	void openGame() { m_count = 0; setState("OpenGame"); }
-	void pause() { m_count = 0; setState("Pause"); }
-	void resume() { m_count = 0; setState("Play"); }
-	void finish() { m_count = 0; setState("Finish"); }
+	void newGame() override
+	{
+		m_count = 0;
+		setState("NewGame");
+	}
+
+	void openGame() override
+	{
+		m_count = 0;
+		setState("OpenGame");
+	}
+
+	void pause() override
+	{
+		m_count = 0;
+		setState("Pause");
+	}
+
+	void resume() override
+	{
+		m_count = 0;
+		setState("Play");
+	}
+
+	void finish() override
+	{
+		m_count = 0;
+		setState("Finish");
+	}
 
 private:
-	int m_count;
+	int m_count; /**< reference count of how many times automatic pause has been entered */
 };
 
 //-----------------------------------------------------------------------------
 
-class Window::PauseState : public Window::State {
+/**
+ * The Window::PauseState class shows the pause screen. It will switch to the play state when
+ * hidden. The base class handles switching to the new or open states when requested.
+ */
+class Window::PauseState : public Window::State
+{
 public:
-	PauseState(Window* window)
-		: State(window) { }
+	explicit PauseState(Window* window)
+		: State(window)
+	{
+	}
 
-	void enter() {
+	void enter() override
+	{
 		setPaused(true);
 		setContentsIndex(1);
 	}
 
-	void resume() { setState("Play"); }
+	void resume() override
+	{
+		setState("Play");
+	}
 };
 
 //-----------------------------------------------------------------------------
 
-class Window::FinishState : public Window::State {
+/**
+ * The Window::FinishState class shows the main play area and does not switch to any other state
+ * like pause or automatic pause, because the game is already over. The base class handles switching
+ * to the new or open states when requested.
+ */
+class Window::FinishState : public Window::State
+{
 public:
-	FinishState(Window* window)
-		: State(window) { }
+	explicit FinishState(Window* window)
+		: State(window)
+	{
+	}
 
-	void enter() {
+	void enter() override
+	{
 		setPaused(false);
 		setContentsIndex(0);
 	}
@@ -240,46 +439,10 @@ public:
 
 //-----------------------------------------------------------------------------
 
-namespace
-{
-	class AboutDialog : public QDialog
-	{
-	public:
-		AboutDialog(const QString& title, const QString& filename, QWidget* parent = 0);
-	};
-
-	AboutDialog::AboutDialog(const QString& title, const QString& filename, QWidget* parent)
-		: QDialog(parent)
-	{
-		setWindowTitle(title);
-
-		QTextEdit* text = new QTextEdit(this);
-		text->setWordWrapMode(QTextOption::NoWrap);
-		text->setReadOnly(true);
-
-		QFile file(filename);
-		if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-			QTextStream stream(&file);
-			text->setHtml("<pre>" + stream.readAll() + "</pre>");
-			file.close();
-		}
-
-		QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Ok, Qt::Horizontal, this);
-		buttons->setCenterButtons(style()->styleHint(QStyle::SH_MessageBox_CenterButtons));
-		connect(buttons, &QDialogButtonBox::accepted, this, &AboutDialog::accept);
-
-		QVBoxLayout* layout = new QVBoxLayout(this);
-		layout->addWidget(text);
-		layout->addWidget(buttons);
-
-		resize(700, 500);
-	}
-}
-
-//-----------------------------------------------------------------------------
-
 Window::Window(const QString& file)
-: m_pause_action(0), m_previous_state(0) {
+	: m_pause_action(nullptr)
+	, m_previous_state(nullptr)
+{
 	setAcceptDrops(true);
 
 	// Create states
@@ -332,12 +495,12 @@ Window::Window(const QString& file)
 
 	// Create game menu
 	QMenu* menu = menuBar()->addMenu(tr("&Game"));
-	menu->addAction(tr("New &Game..."), this, SLOT(newGame()), tr("Ctrl+Shift+N"));
-	menu->addAction(tr("&New Roll"), this, SLOT(newRoll()), QKeySequence::New);
-	menu->addAction(tr("&Choose..."), this, SLOT(chooseGame()));
-	menu->addAction(tr("&Share..."), this, SLOT(shareGame()));
+	menu->addAction(tr("New &Game..."), this, &Window::newGame, tr("Ctrl+Shift+N"));
+	menu->addAction(tr("&New Roll"), this, &Window::newRoll, QKeySequence::New);
+	menu->addAction(tr("&Choose..."), this, &Window::chooseGame, QKeySequence::Open);
+	menu->addAction(tr("&Share..."), this, &Window::shareGame, QKeySequence::Save);
 	menu->addSeparator();
-	QAction* end_action = menu->addAction(tr("&End"), this, SLOT(endGame()));
+	QAction* end_action = menu->addAction(tr("&End"), this, &Window::endGame);
 	end_action->setEnabled(false);
 	connect(m_board, &Board::pauseAvailable, end_action, &QAction::setEnabled);
 	m_pause_action = menu->addAction(tr("&Pause"));
@@ -347,11 +510,11 @@ Window::Window(const QString& file)
 	connect(m_pause_action, &QAction::triggered, this, &Window::setPaused);
 	connect(m_board, &Board::pauseAvailable, m_pause_action, &QAction::setEnabled);
 	menu->addSeparator();
-	m_details_action = menu->addAction(tr("&Details"), this, SLOT(showDetails()));
+	m_details_action = menu->addAction(tr("&Details"), this, &Window::showDetails);
 	m_details_action->setEnabled(false);
-	menu->addAction(tr("&High Scores"), this, SLOT(showScores()));
+	menu->addAction(tr("&High Scores"), this, &Window::showScores, tr("Ctrl+H"));
 	menu->addSeparator();
-	QAction* action = menu->addAction(tr("&Quit"), this, SLOT(close()), tr("Ctrl+Q"));
+	QAction* action = menu->addAction(tr("&Quit"), this, &Window::close, tr("Ctrl+Q"));
 	action->setMenuRole(QAction::QuitRole);
 	monitorVisibility(menu);
 
@@ -376,23 +539,19 @@ Window::Window(const QString& file)
 	counts_action->setCheckable(true);
 	counts_action->setChecked(true);
 	connect(counts_action, &QAction::toggled, m_board, &Board::setShowWordCounts);
-	menu->addAction(tr("&Board Language..."), this, SLOT(showLanguage()));
+	menu->addAction(tr("&Board Language..."), this, &Window::showLanguage);
 	menu->addSeparator();
-	menu->addAction(tr("Application &Language..."), this, SLOT(showLocale()));
+	menu->addAction(tr("Application &Language..."), this, &Window::showLocale);
 	monitorVisibility(menu);
 
 	// Create help menu
 	menu = menuBar()->addMenu(tr("&Help"));
-	menu->addAction(tr("&Controls"), this, SLOT(showControls()));
+	menu->addAction(tr("&Controls"), this, &Window::showControls);
 	menu->addSeparator();
-	action = menu->addAction(tr("&About"), this, SLOT(about()));
+	action = menu->addAction(tr("&About"), this, &Window::about);
 	action->setMenuRole(QAction::AboutRole);
-	action = menu->addAction(tr("About &Hspell"), this, SLOT(aboutHspell()));
-	action->setMenuRole(QAction::ApplicationSpecificRole);
-	action = menu->addAction(tr("About &Qt"), qApp, SLOT(aboutQt()));
+	action = menu->addAction(tr("About &Qt"), qApp, &QApplication::aboutQt);
 	action->setMenuRole(QAction::AboutQtRole);
-	action = menu->addAction(tr("About &SCOWL"), this, SLOT(aboutScowl()));
-	action->setMenuRole(QAction::ApplicationSpecificRole);
 	monitorVisibility(menu);
 
 	// Load settings
@@ -424,7 +583,8 @@ Window::Window(const QString& file)
 
 //-----------------------------------------------------------------------------
 
-bool Window::eventFilter(QObject* watched, QEvent* event) {
+bool Window::eventFilter(QObject* watched, QEvent* event)
+{
 	if (watched == m_pause_screen) {
 		if (event->type() == QEvent::MouseButtonPress) {
 			m_state->resume();
@@ -446,14 +606,16 @@ bool Window::eventFilter(QObject* watched, QEvent* event) {
 
 //-----------------------------------------------------------------------------
 
-void Window::closeEvent(QCloseEvent* event) {
+void Window::closeEvent(QCloseEvent* event)
+{
 	QSettings().setValue("Geometry", saveGeometry());
 	QMainWindow::closeEvent(event);
 }
 
 //-----------------------------------------------------------------------------
 
-void Window::dragEnterEvent(QDragEnterEvent* event) {
+void Window::dragEnterEvent(QDragEnterEvent* event)
+{
 	if (!(event->possibleActions() & Qt::CopyAction)) {
 		return;
 	}
@@ -483,7 +645,8 @@ void Window::dragEnterEvent(QDragEnterEvent* event) {
 
 //-----------------------------------------------------------------------------
 
-void Window::dropEvent(QDropEvent* event) {
+void Window::dropEvent(QDropEvent* event)
+{
 	if (!(event->possibleActions() & Qt::CopyAction)) {
 		return;
 	}
@@ -522,7 +685,8 @@ void Window::dropEvent(QDropEvent* event) {
 
 //-----------------------------------------------------------------------------
 
-bool Window::event(QEvent* event) {
+bool Window::event(QEvent* event)
+{
 	if (m_pause_action && m_pause_action->isEnabled()) {
 		switch (event->type()) {
 		case QEvent::WindowDeactivate:
@@ -545,12 +709,13 @@ bool Window::event(QEvent* event) {
 
 //-----------------------------------------------------------------------------
 
-void Window::about() {
+void Window::about()
+{
 	QMessageBox::about(this, tr("About"),
 		QString("<center><p><big><b>%1</b></big><br/>%2<br/><small>%3<br/>%4</small></p><p>%5</p><p>%6</p></center>")
 		.arg(tr("Tanglet %1").arg(QCoreApplication::applicationVersion()),
 			tr("A single player variant of <a href=\"http://en.wikipedia.org/wiki/Boggle\">Boggle</a>"),
-			tr("Copyright &copy; 2009-%1 Graeme Gott").arg("2020"),
+			tr("Copyright &copy; 2009-%1 Graeme Gott").arg("2021"),
 			tr("Released under the <a href=\"http://www.gnu.org/licenses/gpl.html\">GPL 3</a> license"),
 			tr("English word list is based on <a href=\"http://wordlist.sourceforge.net/\">SCOWL</a> by Kevin Atkinson"),
 			tr("Hebrew word list is based on <a href=\"http://hspell.ivrix.org.il/\">Hspell</a> by Nadav Har'El and Dan Kenigsberg"))
@@ -559,21 +724,8 @@ void Window::about() {
 
 //-----------------------------------------------------------------------------
 
-void Window::aboutHspell() {
-	AboutDialog dialog(tr("About Hspell"), ":/hspell-readme", this);
-	dialog.exec();
-}
-
-//-----------------------------------------------------------------------------
-
-void Window::aboutScowl() {
-	AboutDialog dialog(tr("About SCOWL"), ":/scowl-readme", this);
-	dialog.exec();
-}
-
-//-----------------------------------------------------------------------------
-
-void Window::newRoll() {
+void Window::newRoll()
+{
 	if (endGame()) {
 		startGame();
 	}
@@ -581,7 +733,8 @@ void Window::newRoll() {
 
 //-----------------------------------------------------------------------------
 
-void Window::newGame() {
+void Window::newGame()
+{
 	if (endGame()) {
 		NewGameDialog dialog(this);
 		if (dialog.exec() == QDialog::Accepted) {
@@ -593,68 +746,84 @@ void Window::newGame() {
 
 //-----------------------------------------------------------------------------
 
-void Window::chooseGame() {
-	if (endGame()) {
-		QString filename = QFileDialog::getOpenFileName(window(),
-				tr("Import Game"),
-				QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation),
-				tr("Tanglet Games (*.tanglet)"));
-		if (!filename.isEmpty()) {
-			startGame(filename);
-		}
+void Window::chooseGame()
+{
+	if (!endGame()) {
+		return;
 	}
+
+	QString filename = QFileDialog::getOpenFileName(window(),
+			tr("Import Game"),
+			QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation),
+			tr("Tanglet Games (*.tanglet)"));
+	if (filename.isEmpty()) {
+		return;
+	}
+
+	startGame(filename);
 }
 
 //-----------------------------------------------------------------------------
 
-void Window::shareGame() {
+void Window::shareGame()
+{
 	QString filename = QFileDialog::getSaveFileName(window(),
 			tr("Export Game"),
 			QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation),
 			tr("Tanglet Games (*.tanglet)"));
-	if (!filename.isEmpty()) {
-		if (!filename.endsWith(".tanglet")) {
-			filename += ".tanglet";
-		}
 
-		// Share game
-		{
-			QSettings settings;
-			QSettings game(filename, QSettings::IniFormat);
-			game.setValue("Game/Version", 2);
-			game.setValue("Game/Size", settings.value("Current/Size"));
-			game.setValue("Game/Density", settings.value("Current/Density"));
-			game.setValue("Game/Minimum", settings.value("Current/Minimum"));
-			game.setValue("Game/TimerMode", settings.value("Current/TimerMode"));
-			game.setValue("Game/Letters", settings.value("Current/Letters"));
-			game.setValue("Game/Language", settings.value("Current/Language"));
-			game.setValue("Game/Dictionary", settings.value("Current/Dictionary"));
-			game.setValue("Game/Dice", settings.value("Current/Dice"));
-			game.setValue("Game/Words", settings.value("Current/Words"));
+	if (filename.isEmpty()) {
+		return;
+	}
 
-			if (game.value("Game/Language").toInt() == 0) {
-				QFile file(game.value("Game/Dice").toString());
-				if (file.open(QFile::ReadOnly)) {
-					QByteArray data = file.readAll();
-					file.close();
-					game.setValue("Game/Dice", data.toBase64());
-				}
+	if (!filename.endsWith(".tanglet")) {
+		filename += ".tanglet";
+	}
 
-				file.setFileName(game.value("Game/Words").toString());
-				if (file.open(QFile::ReadOnly)) {
-					QByteArray data = file.readAll();
-					file.close();
-					game.setValue("Game/Words", data.toBase64());
-				}
+	// Share game
+	{
+		QSettings settings;
+		settings.beginGroup("Current");
+
+		QSettings game(filename, QSettings::IniFormat);
+		game.beginGroup("Game");
+
+		game.setValue("Version", settings.value("Version"));
+		game.setValue("Size", settings.value("Size"));
+		game.setValue("Density", settings.value("Density"));
+		game.setValue("Minimum", settings.value("Minimum"));
+		game.setValue("TimerMode", settings.value("TimerMode"));
+		game.setValue("Letters", settings.value("Letters"));
+		game.setValue("Locale", settings.value("Locale"));
+		game.setValue("Dictionary", settings.value("Dictionary"));
+
+		const QString dice = settings.value("Dice").toString();
+		if (dice.startsWith("tanglet:")) {
+			game.setValue("Dice", dice);
+		} else {
+			QFile file(dice);
+			if (file.open(QFile::ReadOnly)) {
+				game.setValue("Dice", file.readAll().toBase64());
+			}
+		}
+
+		const QString words = settings.value("Words").toString();
+		if (words.startsWith("tanglet:")) {
+			game.setValue("Words", words);
+		} else {
+			QFile file(words);
+			if (file.open(QFile::ReadOnly)) {
+				game.setValue("Words", file.readAll().toBase64());
 			}
 		}
-		gzip(filename);
 	}
+	gzip(filename);
 }
 
 //-----------------------------------------------------------------------------
 
-bool Window::endGame() {
+bool Window::endGame()
+{
 	if (!m_board->isFinished()) {
 		if (QMessageBox::question(this, tr("Question"), tr("End the current game?"), QMessageBox::Yes | QMessageBox::No, QMessageBox::No) == QMessageBox::Yes) {
 			m_board->abort();
@@ -667,19 +836,22 @@ bool Window::endGame() {
 
 //-----------------------------------------------------------------------------
 
-void Window::autoPause() {
+void Window::autoPause()
+{
 	m_state->autoPause();
 }
 
 //-----------------------------------------------------------------------------
 
-void Window::autoResume() {
+void Window::autoResume()
+{
 	m_state->autoResume();
 }
 
 //-----------------------------------------------------------------------------
 
-void Window::setPaused(bool paused) {
+void Window::setPaused(bool paused)
+{
 	if (paused) {
 		m_state->pause();
 	} else {
@@ -689,7 +861,8 @@ void Window::setPaused(bool paused) {
 
 //-----------------------------------------------------------------------------
 
-void Window::showDetails() {
+void Window::showDetails()
+{
 	QSettings settings;
 	int size = settings.value("Current/Size").toInt();
 	int density = settings.value("Current/Density").toInt();
@@ -710,15 +883,16 @@ void Window::showDetails() {
 
 //-----------------------------------------------------------------------------
 
-void Window::showScores() {
+void Window::showScores()
+{
 	ScoresDialog scores(this);
-	connect(&scores, &ScoresDialog::scoresReset, m_board, &Board::updateScoreColor);
 	scores.exec();
 }
 
 //-----------------------------------------------------------------------------
 
-void Window::showLanguage() {
+void Window::showLanguage()
+{
 	LanguageDialog dialog(this);
 	if (dialog.exec() == QDialog::Accepted) {
 		newGame();
@@ -727,14 +901,16 @@ void Window::showLanguage() {
 
 //-----------------------------------------------------------------------------
 
-void Window::showLocale() {
+void Window::showLocale()
+{
 	LocaleDialog dialog(this);
 	dialog.exec();
 }
 
 //-----------------------------------------------------------------------------
 
-void Window::showControls() {
+void Window::showControls()
+{
 	QMessageBox::information(this, tr("Controls"), tr(
 		"<p><b><big>Mouse Play:</big></b><br>"
 		"<b>Select a word:</b> Click on the letters of a word.<br>"
@@ -750,33 +926,37 @@ void Window::showControls() {
 
 //-----------------------------------------------------------------------------
 
-void Window::optimizingStarted() {
+void Window::optimizingStarted()
+{
 	m_state->optimizingStarted();
 }
 
 //-----------------------------------------------------------------------------
 
-void Window::optimizingFinished() {
+void Window::optimizingFinished()
+{
 	m_state->optimizingFinished();
 }
 
 //-----------------------------------------------------------------------------
 
-void Window::gameStarted() {
+void Window::gameStarted()
+{
 	m_state->play();
 	m_details_action->setEnabled(true);
 }
 
 //-----------------------------------------------------------------------------
 
-void Window::gameFinished(int score) {
+void Window::gameFinished(int score, int max_score)
+{
 	m_state->finish();
 	ScoresDialog scores(this);
-	if (scores.addScore(score)) {
+	if (scores.addScore(score, max_score)) {
 		scores.exec();
 	}
 
-	QDir dir(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
+	QDir dir(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation));
 	dir.remove("current");
 	dir.remove("current-dice");
 	dir.remove("current-words");
@@ -784,7 +964,8 @@ void Window::gameFinished(int score) {
 
 //-----------------------------------------------------------------------------
 
-void Window::monitorVisibility(QMenu* menu) {
+void Window::monitorVisibility(QMenu* menu)
+{
 #ifndef Q_OS_MAC
 	connect(menu, &QMenu::aboutToShow, this, &Window::autoPause);
 	connect(menu, &QMenu::aboutToHide, this, &Window::autoResume);
@@ -793,92 +974,87 @@ void Window::monitorVisibility(QMenu* menu) {
 
 //-----------------------------------------------------------------------------
 
-void Window::startGame(const QString& filename) {
-	QSettings* game = 0;
+void Window::startGame(const QString& filename)
+{
+	QSettings settings;
 
 	if (filename.isEmpty()) {
 		// Start a new game
-		game = new QSettings;
-		game->remove("Current");
-		game->sync();
-		game->beginGroup("Board");
+		settings.remove("Current");
+		settings.sync();
 		m_state->newGame();
+		settings.beginGroup("Board");
+		m_board->generate(settings);
+	} else if (filename == ":saved:") {
+		// Continue previous game
+		m_state->openGame();
+		settings.beginGroup("Current");
+		if (!m_board->generate(settings)) {
+			QMessageBox::warning(this, tr("Error"), tr("Unable to start requested game."));
+			m_state->finish();
+			m_contents->setCurrentIndex(3);
+		}
 	} else {
-		if (filename == ":saved:") {
-			// Continue previous game
-			game = new QSettings;
-			game->beginGroup("Current");
-		} else {
-			QString file = extractGame(filename);
-			if (file.isEmpty()) {
-				QMessageBox::warning(this, tr("Error"), tr("Unable to start requested game."));
-				return;
-			}
+		// Uncompress requested game
+		QString current = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
+		QDir::home().mkpath(current);
+		current += "/current";
 
-			// Start requested game
-			QSettings().remove("Current");
-			game = new QSettings(file, QSettings::IniFormat);
-			game->beginGroup("Game");
-		}
-
-		bool loaded = false;
-		if (game->value("Version").toInt() <= 2) {
-			loaded = !game->value("Letters").toStringList().isEmpty();
-		}
-		if (!loaded) {
+		QByteArray data = gunzip(filename);
+		QFile file(current);
+		if (!file.open(QFile::WriteOnly)) {
 			QMessageBox::warning(this, tr("Error"), tr("Unable to start requested game."));
 			return;
 		}
+		file.write(data);
+		file.close();
 
+		QSettings game(current, QSettings::IniFormat);
+		game.beginGroup("Game");
+
+		// Extract dice
+		data = game.value("Dice").toByteArray();
+		if (data.startsWith("tanglet:")) {
+			game.setValue("Dice", data);
+		} else {
+			const QString dice = QString("%1-dice").arg(current);
+			game.setValue("Dice", dice);
+			file.setFileName(dice);
+			if (!file.open(QFile::WriteOnly)) {
+				QMessageBox::warning(this, tr("Error"), tr("Unable to start requested game."));
+				return;
+			}
+			file.write(QByteArray::fromBase64(data));
+			file.close();
+		}
+
+		// Extract words
+		data = game.value("Words").toByteArray();
+		if (data.startsWith("tanglet:")) {
+			game.setValue("Words", data);
+		} else {
+			const QString words = QString("%1-words").arg(current);
+			game.setValue("Words", words);
+			file.setFileName(words);
+			if (!file.open(QFile::WriteOnly)) {
+				QMessageBox::warning(this, tr("Error"), tr("Unable to start requested game."));
+				return;
+			}
+			file.write(QByteArray::fromBase64(data));
+			file.close();
+		}
+		data.clear();
+
+		// Start requested game
+		settings.remove("Current");
+		settings.sync();
 		m_state->openGame();
+		if (!m_board->generate(game)) {
+			QMessageBox::warning(this, tr("Error"), tr("Unable to start requested game."));
+			m_state->finish();
+			m_contents->setCurrentIndex(3);
+		}
 	}
-
-	m_board->generate(*game);
-	delete game;
-}
-
-//-----------------------------------------------------------------------------
-
-QString Window::extractGame(const QString& filename) const {
-	QString current = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
-
-	// Uncompress shared game
-	const QDir dir = QDir::home();
-	dir.mkpath(current);
-	current += "/current";
-
-	const QByteArray data = gunzip(filename);
-	QFile file(current);
-	if (!file.open(QFile::WriteOnly)) {
-		return QString();
-	}
-	file.write(data);
-	file.close();
-
-	// Extract words and dice
-	QSettings game(current, QSettings::IniFormat);
-
-	if (game.value("Game/Language", -1).toInt() == 0) {
-		const QByteArray dice = QByteArray::fromBase64(game.value("Game/Dice").toByteArray());
-		game.setValue("Game/Dice", current + "-dice");
-		file.setFileName(current + "-dice");
-		if (!file.open(QFile::WriteOnly)) {
-			return QString();
-		}
-		file.write(dice);
-		file.close();
-
-		const QByteArray words = QByteArray::fromBase64(game.value("Game/Words").toByteArray());
-		game.setValue("Game/Words", current + "-words");
-		file.setFileName(current + "-words");
-		if (!file.open(QFile::WriteOnly)) {
-			return QString();
-		}
-		file.write(words);
-		file.close();
-	}
-
-	return current;
 }
 
 //-----------------------------------------------------------------------------
