@@ -1,21 +1,8 @@
-/***********************************************************************
- *
- * Copyright (C) 2012, 2017 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2012-2020 Graeme Gott <graeme@gottcode.org>
+
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include <QByteArray>
 #include <QCommandLineOption>
@@ -29,6 +16,7 @@
 
 #include <algorithm>
 #include <iostream>
+#include <map>
 #include <random>
 #include <stdexcept>
 #include <unordered_map>
@@ -46,24 +34,26 @@ public:
 
 namespace std
 {
-	template <>
-	struct hash<QChar>
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+template <>
+struct hash<QChar>
+{
+	size_t operator()(const QChar& k) const
 	{
-		size_t operator()(const QChar& k) const
-		{
-			return qHash(k);
-		}
-	};
+		return qHash(k);
+	}
+};
+#endif
 
 #if (QT_VERSION < QT_VERSION_CHECK(5,14,0))
-	template <>
-	struct hash<QString>
+template <>
+struct hash<QString>
+{
+	size_t operator()(const QString& k) const
 	{
-		size_t operator()(const QString& k) const
-		{
-			return qHash(k);
-		}
-	};
+		return qHash(k);
+	}
+};
 #endif
 }
 
@@ -98,7 +88,9 @@ std::vector<QString> readWords(const QString& path)
 	// Find words
 	std::vector<QString> words;
 	QTextStream stream(&data);
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
 	stream.setCodec("UTF-8");
+#endif
 	while (!stream.atEnd()) {
 		words.push_back(stream.readLine().trimmed().split(' ').first().toUpper());
 	}
@@ -116,7 +108,9 @@ void saveDice(const QString& path, const std::vector<QString>& small, const std:
 	}
 
 	QTextStream stream(&out);
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
 	stream.setCodec("UTF-8");
+#endif
 
 	for (const QString& line : small) {
 		stream << line << '\n';
@@ -147,7 +141,7 @@ std::unordered_map<QString, qreal> findLetterFrequency(const std::vector<QString
 				++chars[c];
 			}
 		}
-		for (auto i = chars.cbegin(); i != chars.cend(); ++i) {
+		for (auto i = chars.cbegin(), end = chars.cend(); i != end; ++i) {
 			letters.emplace(i->first, i->second);
 		}
 	}
@@ -159,10 +153,10 @@ std::unordered_map<QString, qreal> findLetterFrequency(const std::vector<QString
 			if (probability < 0.001) {
 				total -= i->second;
 				std::cout << QString("Discarded '%1', probability: %2%")
-					.arg(i->first)
-					.arg(probability, 0, 'f')
-					.toStdString()
-					<< std::endl;
+						.arg(i->first)
+						.arg(probability, 0, 'f')
+						.toStdString()
+						<< std::endl;
 				i = letters.erase(i);
 				if (i == letters.end()) {
 					break;
@@ -188,12 +182,12 @@ std::unordered_map<QString, qreal> findLetterFrequency(const std::vector<QString
 		// Find letters where bigrams are 99% of occurrences
 		std::unordered_map<QString, QString> replace;
 		std::unordered_map<QString, int> confidences;
-		for (auto i = letters.cbegin(); i != letters.cend(); ++i) {
+		for (auto i = letters.cbegin(), end = letters.cend(); i != end; ++i) {
 			const QString& letter = i->first;
 
 			int letter_count = 0;
 			std::vector<QString> letter_bigrams;
-			for (auto b = bigrams.cbegin(); b != bigrams.cend(); ++b) {
+			for (auto b = bigrams.cbegin(), end_b = bigrams.cend(); b != end_b; ++b) {
 				const QString& bigram = b->first;
 				if (bigram.startsWith(letter)) {
 					letter_bigrams.push_back(bigram);
@@ -212,7 +206,7 @@ std::unordered_map<QString, qreal> findLetterFrequency(const std::vector<QString
 		}
 
 		// Replace letter with bigram
-		for (auto i = replace.cbegin(); i != replace.cend(); ++i) {
+		for (auto i = replace.cbegin(), end = replace.cend(); i != end; ++i) {
 			const QString& letter = i->first;
 			const QString& bigram = i->second;
 			const int count = bigrams[bigram];
@@ -224,18 +218,18 @@ std::unordered_map<QString, qreal> findLetterFrequency(const std::vector<QString
 			total -= count;
 
 			std::cout << QString("Replaced '%1' with '%2', confidence: %3%")
-				.arg(letter)
-				.arg(letter + bigram[1].toLower())
-				.arg(confidences[letter])
-				.toStdString()
-				<< std::endl;
+					.arg(letter)
+					.arg(letter + bigram[1].toLower())
+					.arg(confidences[letter])
+					.toStdString()
+					<< std::endl;
 		}
 	}
 
 	// Adjust letter frequencies to be in the range 0-1
 	std::unordered_map<QString, qreal> result;
 	const qreal inverse_total = 1.0 / qreal(total);
-	for (auto i = letters.cbegin(); i != letters.cend(); ++i) {
+	for (auto i = letters.cbegin(), end = letters.cend(); i != end; ++i) {
 		result.emplace(i->first, i->second * inverse_total);
 	}
 	return result;
@@ -250,7 +244,7 @@ std::unordered_map<QString, int> roundLetters(const std::unordered_map<QString,
 	// Scale letters by dice sides
 	std::unordered_map<QString, qreal> scaled;
 	std::vector<QString> frequent;
-	for (auto i = letters.cbegin(); i != letters.cend(); ++i) {
+	for (auto i = letters.cbegin(), end = letters.cend(); i != end; ++i) {
 		qreal value = i->second * sides;
 		if (value < 1.0) {
 			value = 1.0;
@@ -260,7 +254,7 @@ std::unordered_map<QString, int> roundLetters(const std::unordered_map<QString,
 
 		// Track letter frequency
 		auto f = frequent.begin();
-		for (; f != frequent.end(); ++f) {
+		for (auto end_f = frequent.end(); f != end_f; ++f) {
 			if (value > scaled[*f]) {
 				break;
 			}
@@ -268,11 +262,15 @@ std::unordered_map<QString, int> roundLetters(const std::unordered_map<QString,
 		frequent.insert(f, letter);
 	}
 
-	// Round letters
+	// Round letters by 2 digits after decimal
+	std::map<qreal, QString> deltas;
 	std::unordered_map<QString, int> result;
 	int rounded = 0;
 	for (const auto& letter : frequent) {
-		const int value = std::round(scaled[letter]);
+		const int value = std::lround(std::round(scaled[letter] * 10.0) / 10.0);
+		if (value > 1) {
+			deltas[std::abs(value + 0.5 - scaled[letter])] = letter;
+		}
 		result[letter] = value;
 		rounded += value;
 	}
@@ -280,11 +278,16 @@ std::unordered_map<QString, int> roundLetters(const std::unordered_map<QString,
 		throw Exception("Rounded frequencies are less than dice sides.");
 	}
 
-	// Reduce most frequent letters so that the letter count matches sides
+	// Reduce closest rounded letters so that letter count matches sides
 	rounded -= sides;
+	auto letter = deltas.rbegin();
 	for (int i = 0; i < rounded; ++i) {
-		if (--result[frequent[i]] == 0) {
-			throw Exception("'" + frequent[i] + "' has frequency of 0.");
+		if (--result[letter->second] == 0) {
+			throw Exception("'" + letter->second + "' has frequency of 0.");
+		}
+		++letter;
+		if (letter == deltas.rend()) {
+			throw Exception("Not enough closely rounded frequencies to match sides.");
 		}
 	}
 
@@ -301,7 +304,7 @@ std::vector<QString> generateDice(const std::unordered_map<QString, qreal>& lett
 	const auto scaled_letters = roundLetters(letters, count);
 	std::vector<QString> single_letters;
 	std::vector<QString> multi_letters;
-	for (auto i = scaled_letters.cbegin(); i != scaled_letters.cend(); ++i) {
+	for (auto i = scaled_letters.cbegin(), end = scaled_letters.cend(); i != end; ++i) {
 		const QString& letter = i->first;
 		const int& value = i->second;
 		if (value == 1) {
@@ -355,16 +358,11 @@ int main(int argc, char** argv)
 		QCommandLineParser parser;
 		parser.setApplicationDescription("Create Tanglet dice from a Tanglet word list.");
 		parser.addHelpOption();
-		parser.addOption(QCommandLineOption({"b", "bigrams"},
-			"Automatically detect bigrams."));
-		parser.addOption(QCommandLineOption({"d", "discard"},
-			"Discard infreqeunt letters."));
-		parser.addOption(QCommandLineOption({"o", "output"},
-			"Place dice in <output> instead of default file.", "output"));
-		parser.addOption(QCommandLineOption({"s", "seed"},
-			"Specify random <seed>.", "seed"));
-		parser.addOption(QCommandLineOption({"v", "verbose"},
-			"Print status messages."));
+		parser.addOption(QCommandLineOption({"b", "bigrams"}, "Automatically detect bigrams."));
+		parser.addOption(QCommandLineOption({"d", "discard"}, "Discard infreqeunt letters."));
+		parser.addOption(QCommandLineOption({"o", "output"}, "Place dice in <output> instead of default file.", "output"));
+		parser.addOption(QCommandLineOption({"s", "seed"}, "Specify random <seed>.", "seed"));
+		parser.addOption(QCommandLineOption({"v", "verbose"}, "Print status messages."));
 		parser.addPositionalArgument("file", "The <file> to analyze for letter frequency.");
 		parser.process(app);
 
