@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Details</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Löschen</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Versuchen</translation>
@@ -170,6 +166,14 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Zählt von 30 Sekunden abwärts und erhöht oder verringert bei Versuchen.</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation>Unbegrenzt</translation>
+    </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation>Spiel endet, wenn alle Wörter gefunden sind.</translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -289,32 +293,52 @@
         <translation>Highscores</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Name&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Name</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Score&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Score</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Datum&lt;/b&gt;</translation>
-    </message>
-    <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Zeitlimit&lt;/b&gt;</translation>
+        <source>Date</source>
+        <translation>Datum</translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>%1.</translation>
     </message>
     <message>
-        <source>Question</source>
-        <translation>Frage</translation>
+        <source>Rank</source>
+        <translation>Rang</translation>
     </message>
     <message>
-        <source>Clear high scores?</source>
-        <translation>Highscores löschen?</translation>
+        <source>Maximum</source>
+        <translation>Maximum</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation>Größe</translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation>Glückwunsch!</translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation>Sie haben Ihren Highscore geschlagen!</translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation>Gut gemacht!</translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation>Sie haben einen neuen Highscore!</translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation>–</translation>
     </message>
 </context>
 <context>
@@ -353,7 +377,7 @@
     </message>
     <message>
         <source>Ctrl+Shift+N</source>
-        <translation>Ctrl+Shift+N</translation>
+        <translation>Strg+Shift+N</translation>
     </message>
     <message>
         <source>&amp;New Roll</source>
@@ -377,7 +401,7 @@
     </message>
     <message>
         <source>Ctrl+P</source>
-        <translation>Ctrl+P</translation>
+        <translation>Strg+P</translation>
     </message>
     <message>
         <source>&amp;Details</source>
@@ -393,7 +417,7 @@
     </message>
     <message>
         <source>Ctrl+Q</source>
-        <translation>Ctrl+Q</translation>
+        <translation>Strg+Q</translation>
     </message>
     <message>
         <source>&amp;Settings</source>
@@ -443,18 +467,10 @@
         <source>&amp;About</source>
         <translation>Ü&amp;ber</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Über &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Über &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Über &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -483,14 +499,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Hebräische Wortliste basiert auf &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; von Nadav Har&apos;El und Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Über Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Über SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Spiel importieren</translation>
@@ -563,6 +571,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mit der Maus:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wort auswählen:&lt;/b&gt; Auf die Buchstaben eines Worts klicken.&lt;br&gt;&lt;b&gt;Einen Versuch machen:&lt;/b&gt; Auf den zuletzt ausgewählten Buchstaben klicken.&lt;br&gt;&lt;b&gt;Buchstaben entfernen:&lt;/b&gt; Auf einen vorher ausgewählten Buchstaben klicken.&lt;br&gt;&lt;b&gt;Wort löschen:&lt;/b&gt; Zweimal auf den ersten ausgewählten Buchstaben klicken.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Mit der Tastatur:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Wort auswählen:&lt;/b&gt; Die Buchstaben eines Worts tippen.&lt;br&gt;&lt;b&gt;Einen Versuch machen:&lt;/b&gt; Eingabetaste drücken.&lt;br&gt;&lt;b&gt;Wort löschen:&lt;/b&gt; Strg+Backspace drücken.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation>Strg+H</translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
