@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Λεπτομέρειες</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Εκκαθάριση</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Εικασία</translation>
@@ -142,6 +138,10 @@
         <source>Discipline</source>
         <translation>Πειθαρχία</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Αντίστροφη μέτρηση 30&apos;&apos; κι αύξηση σε περίπτωση σωστής πρόβλεψης.</translation>
@@ -170,6 +170,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Αντίστροφη μέτρηση 30&apos;&apos; κι αύξηση ή μείωση, μετά τη πρόβλεψη.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -289,33 +293,53 @@
         <translation>Μεγαλύτερες Βαθμολογίες</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Όνομα&lt;/b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Βαθμολογία&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Όνομα</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Ημερομηνία&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Βαθμολογία</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Χρόνος&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Ημερομηνία</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Ερώτηση</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>Καθαρισμός Μεγαλύτερων Βαθμολογιών</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -443,18 +467,10 @@
         <source>&amp;About</source>
         <translation>&amp;Σχετικά</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Σχετικά &amp;με το HSpell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Σχετικά &amp;με το Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Σχετικά &amp;με το SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Συγγραφέας &amp;δικαιώματα; 2009-%1 Graeme Gott</translation>
@@ -483,14 +499,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Ο Εβραϊκός κατάλογος λέξεων, βασίστηκε στο &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; των Nadav Har&apos;El και Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Σχετικά με το Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Σχετικά με το SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Εισαγωγή παιχνιδιού</translation>
@@ -563,6 +571,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Παιχνίδι Ποντικιού:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Επιλέξτε λέξη:&lt;/b&gt; Κλικ στα γράμματα της λέξης.&lt;br&gt;&lt;b&gt;Κάντε μια πρόβλεψη:&lt;/b&gt; Κλικ στο τελευταίο επιλεγμένο γράμμα.&lt;br&gt;&lt;b&gt;Διαγράψτε γράμματα:&lt;/b&gt;Κλικ σε προηγουμένως επιλεγμέν γράμμα.&lt;br&gt;&lt;b&gt;Καθαρισμός λέξης:&lt;/b&gt;Διπλό κλικ στο πρώτο επιλεγμένο γράμμα.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Παιχνίδι Πληκτρολογίου:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Επιλέξτε λέξη:&lt;/b&gt; Πληκτρολογήστε τα γράμματα της λέξης.&lt;br&gt;&lt;b&gt;Κάντε μια πρόβλεψη:&lt;/b&gt; Πατήστε Enter.&lt;br&gt;&lt;b&gt;Καθαρισμός λέξης:&lt;/b&gt; Πατήστε Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
