@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Dettagli</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Azzera</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Risposta</translation>
@@ -142,6 +138,10 @@
         <source>Discipline</source>
         <translation>Disciplina</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Conto alla rovescia da 30 secondi e aumenta su risposte corrette.</translation>
@@ -170,6 +170,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Conto alla rovescia da 30 secondi e cresce o decresce in base alle risposte.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -289,33 +293,53 @@
         <translation>Punteggi massimi</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Nome&lt;/b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Punteggio&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Nome</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Data&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Punteggio</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Timer&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Data</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Domanda</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>Cancella punteggi massimi ?</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -443,18 +467,10 @@
         <source>&amp;About</source>
         <translation>&amp;Informazioni su</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Informazioni su &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Informazioni su &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Informazioni su &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -483,14 +499,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>La lista  di parole ebraiche è basata su &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; di Nadav Har&apos;El and Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Informazioni su Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Informazioni su SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Importa partita</translation>
@@ -563,6 +571,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Gioca col mouse:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Seleziona una parola:&lt;/b&gt; Clicca sulle lettere di una parola.&lt;br&gt;&lt;b&gt;Crea una risposta:&lt;/b&gt; Clicca sull&apos;ultima lettera selezionata.&lt;br&gt;&lt;b&gt;Cancella le  lettere:&lt;/b&gt; Clicca sulla prima lettera selezionata.&lt;br&gt;&lt;b&gt;Cancella la parola:&lt;/b&gt; Clicca due volte sulla prima lettera selezionata.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Gioca con la tastiera:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Seleziona una parola:&lt;/b&gt; Scrivi le lettere di una palora.&lt;br&gt;&lt;b&gt;Dai una risposta:&lt;/b&gt; Premi invio.&lt;br&gt;&lt;b&gt;Cancella la word:&lt;/b&gt; Premi Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
