@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Perincian</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Kosongkan</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Teka</translation>
@@ -134,6 +130,10 @@
         <source>Discipline</source>
         <translation>Disiplin</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Kiraan mengundur bermula dari 30 saat dan meningkat jika tekaan betul</translation>
@@ -162,6 +162,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Kiraan mengundur bermula dari 30 saat dan meningkat atau menurun mengikut tekaan.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -280,33 +284,53 @@
         <translation>Skor Tertinggi</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Nama&lt;/b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Skor&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Nama</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Tarikh&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Skor</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Pemasa&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Tarikh</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>#%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Soalan</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>Kosongkan skor tertinggi?</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -434,18 +458,10 @@
         <source>&amp;About</source>
         <translation>Perih&amp;al</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Perihal &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Perihal &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Perihal </translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Hakcipta &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -474,14 +490,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Senarai perkataan Bahasa Ibrani berasaskan pada &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; oleh Nadav Har&apos;El dan Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Perihal Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Perihal SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Import Permainan</translation>
@@ -554,6 +562,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Main Menggunakan Tetikus:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pilih perkataan:&lt;/b&gt; Klik pada abjad perkataan.&lt;br&gt;&lt;b&gt;Buat tekaan:&lt;/b&gt; Klik pada abjad terpilih yang terakhir.&lt;br&gt;&lt;b&gt;Padam abjad:&lt;/b&gt; Klik pada abjad terpilih yang awal.&lt;br&gt;&lt;b&gt;Kosongkan perkataan:&lt;/b&gt; Klik dua kali pada abjad terpilih yang pertama.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Main Menggunakan Papan Kekunci:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Pilih perkataan:&lt;/b&gt; Taip abjad perkataan tersebut.&lt;br&gt;&lt;b&gt;Buat tekaan:&lt;/b&gt; Tekan Enter.&lt;br&gt;&lt;b&gt;Kosongkan perkataan:&lt;/b&gt; Tekan Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
