@@ -7,10 +7,6 @@
         <source>Details</source>
         <translation>Details</translation>
     </message>
-    <message>
-        <source>Clear</source>
-        <translation>Legen</translation>
-    </message>
     <message>
         <source>Guess</source>
         <translation>Raden</translation>
@@ -142,6 +138,10 @@
         <source>Discipline</source>
         <translation>Vriezen of dooien</translation>
     </message>
+    <message>
+        <source>Unlimited</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>Counts down from 30 seconds and increases on correct guesses.</source>
         <translation>Begint op 30 seconden, neemt toe bij een goed antwoord.</translation>
@@ -170,6 +170,10 @@
         <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
         <translation>Begint op 30 seconden, neemt toe of af afhankelijk van het antwoord.</translation>
     </message>
+    <message>
+        <source>Game ends when all words are found.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Generator</name>
@@ -289,33 +293,53 @@
         <translation>Topscores</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Name&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Naam&lt;b&gt;</translation>
+        <source>Rank</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&lt;b&gt;Score&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Score&lt;/b&gt;</translation>
+        <source>Name</source>
+        <translation>Naam</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Date&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Datum&lt;/b&gt;</translation>
+        <source>Score</source>
+        <translation>Score</translation>
     </message>
     <message>
-        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
-        <translation>&lt;b&gt;Spelvariant&lt;/b&gt;</translation>
+        <source>Maximum</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation>Datum</translation>
+    </message>
+    <message>
+        <source>Size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Congratulations!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You beat your top score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Well done!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You have a new high score!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>N/A</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>#%1</source>
         <translation>%1</translation>
     </message>
-    <message>
-        <source>Question</source>
-        <translation>Vraag</translation>
-    </message>
-    <message>
-        <source>Clear high scores?</source>
-        <translation>Wilt u de topscores verwijderen?</translation>
-    </message>
 </context>
 <context>
     <name>Window</name>
@@ -443,18 +467,10 @@
         <source>&amp;About</source>
         <translation>&amp;Info</translation>
     </message>
-    <message>
-        <source>About &amp;Hspell</source>
-        <translation>Info over &amp;Hspell</translation>
-    </message>
     <message>
         <source>About &amp;Qt</source>
         <translation>Info over &amp;Qt</translation>
     </message>
-    <message>
-        <source>About &amp;SCOWL</source>
-        <translation>Info over &amp;SCOWL</translation>
-    </message>
     <message>
         <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
         <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
@@ -483,14 +499,6 @@
         <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
         <translation>Hebreeuwse woordenlijst gebaseerd op &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; van Nadav Har&apos;El en Dan Kenigsberg</translation>
     </message>
-    <message>
-        <source>About Hspell</source>
-        <translation>Info over Hspell</translation>
-    </message>
-    <message>
-        <source>About SCOWL</source>
-        <translation>Info over SCOWL</translation>
-    </message>
     <message>
         <source>Import Game</source>
         <translation>Spel importeren</translation>
@@ -563,6 +571,10 @@
         <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
         <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Met de muis spelen:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Een woord selecteren:&lt;/b&gt; Klik op de letters van het woord.&lt;br&gt;&lt;b&gt;Een woord raden:&lt;/b&gt; Klik op de laatste letter van het woord.&lt;br&gt;&lt;b&gt;Een letter wissen:&lt;/b&gt; Klik op een eerder geselecteerde letter.&lt;br&gt;&lt;b&gt;Een woord wissen:&lt;/b&gt; Dubbelklik op de eerste letter van het woord.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Met het toetsenbord spelen:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Een woord selecteren:&lt;/b&gt; Typ de letters van het woord.&lt;br&gt;&lt;b&gt;Een woord raden:&lt;/b&gt; Druk op Enter.&lt;br&gt;&lt;b&gt;Een woord wissen:&lt;/b&gt; Druk op Ctrl+Backspace.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>Ctrl+H</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WordCounts</name>
